# @jupyterlab/launcher

A JupyterLab package that provides a launcher for various activities,
including notebooks, consoles, text editors, and terminals.

JupyterLab extensions may register themselves with the launcher in order to show up as an activity when the application starts.
